-- -----------------------------------------------------
-- Table SCF_OBJECT_ZONE_SYNC
-- -----------------------------------------------------
CREATE  TABLE SCF_OBJECT_ZONE_SYNC (
  OBJECT_ZONE_SYNC_ID INTEGER  NOT NULL ,
  SIF_OBJECT_NAME VARCHAR(45) NULL ,
  ZONE_ID VARCHAR(45) NULL ,
  AGENT_ID VARCHAR(45) NULL ,
  LAST_REQUESTED TIMESTAMP NULL  ,
  PRIMARY KEY (OBJECT_ZONE_SYNC_ID) );

CREATE INDEX IX_OBJECT_SYNC_NAME_ZONE ON SCF_OBJECT_ZONE_SYNC (SIF_OBJECT_NAME , ZONE_ID ) ;


-- -----------------------------------------------------
-- Table SCF_OBJECT
-- -----------------------------------------------------
CREATE  TABLE SCF_OBJECT (
  SIF_OBJECT_NAME VARCHAR(45) NOT NULL ,
  KEY_SEPARATOR VARCHAR(3) NULL  ,
  DEFAULT_EXPIRY_IN_MINUTES INTEGER  NULL  ,
  DEFAULT_EXPIRY_STRATEGY VARCHAR(45) NULL  ,
  PRIMARY KEY (SIF_OBJECT_NAME) );

-- -----------------------------------------------------
-- Table SCF_OBJECT_KEY
-- -----------------------------------------------------
CREATE  TABLE SCF_OBJECT_KEY (
  OBJECT_KEY_ID INTEGER  NOT NULL ,
  SIF_OBJECT_NAME VARCHAR(45) NOT NULL ,
  XPATH_TO_KEY VARCHAR(256) NOT NULL ,
  SORT_ORDER INTEGER  NULL ,
  PRIMARY KEY (OBJECT_KEY_ID) ,
  CONSTRAINT fk_SCF_OBJECT_KEY_SCF_OBJECT1
    FOREIGN KEY (SIF_OBJECT_NAME )
    REFERENCES SCF_OBJECT (SIF_OBJECT_NAME ));

CREATE INDEX fk_SCF_OBJECT_KEY_SCF_OBJECT1 ON SCF_OBJECT_KEY (SIF_OBJECT_NAME ) ;

CREATE INDEX IX_OBJECT_KEY_KEY_ORDER ON SCF_OBJECT_KEY (SIF_OBJECT_NAME , SORT_ORDER ) ;


-- -----------------------------------------------------
-- Table SCF_DO_CACHE
-- -----------------------------------------------------
CREATE  TABLE SCF_DO_CACHE (
  DO_CACHE_ID INTEGER  NOT NULL ,
  SIF_OBJECT_NAME VARCHAR(45) NULL ,
  OBJECT_KEY_VALUE VARCHAR(256) NULL  ,
  IS_EVENT BOOLEAN  NULL ,
  EVENT_TYPE VARCHAR(10) NULL ,
  OBJECT_XML TEXT NULL ,
  RECEIVED_DATE TIMESTAMP NULL ,
  AGENT_ID VARCHAR(45) NULL ,
  APPLICATION_ID VARCHAR(45) NULL  ,
  ZONE_ID VARCHAR(45) NULL ,
  DEPENENCY_REMAINING INTEGER  NULL  ,
  EXPIRY_DATE TIMESTAMP NULL  ,
  EXPIRY_STRATEGY VARCHAR(45) NULL  ,
  PRIMARY KEY (DO_CACHE_ID) ,
  CONSTRAINT fk_SCF_DOC_SCF_OBJECT1
    FOREIGN KEY (SIF_OBJECT_NAME )
    REFERENCES SCF_OBJECT (SIF_OBJECT_NAME ));

CREATE INDEX fk_SCF_DOC_SCF_OBJECT1 ON SCF_DO_CACHE (SIF_OBJECT_NAME ) ;

CREATE INDEX IX_DO_CACHE_NAME_REMAINING ON SCF_DO_CACHE (SIF_OBJECT_NAME , DEPENENCY_REMAINING ) ;

CREATE INDEX IX_DO_CACHE_NAME_EXPIRY ON SCF_DO_CACHE (SIF_OBJECT_NAME , EXPIRY_DATE ) ;

CREATE INDEX IX_DO_CACHE_EXPIRY ON SCF_DO_CACHE (EXPIRY_DATE ) ;

CREATE INDEX IX_DO_CACHE_NAME_KEY_APPID ON SCF_DO_CACHE (SIF_OBJECT_NAME , OBJECT_KEY_VALUE , APPLICATION_ID , ZONE_ID ) ;


-- -----------------------------------------------------
-- Table SCF_DOC_OBJECT
-- -----------------------------------------------------
CREATE  TABLE SCF_DOC_OBJECT (
  DOC_OBJECT_ID INTEGER  NOT NULL ,
  SIF_OBJECT_NAME VARCHAR(45) NULL ,
  OBJECT_KEY_VALUE VARCHAR(256) NULL ,
  AGENT_ID VARCHAR(45) NULL ,
  APPLICATION_ID VARCHAR(45) NULL  ,
  ZONE_ID VARCHAR(45) NULL ,
  REQUESTED BOOLEAN  NULL  ,
  REQUEST_DATE TIMESTAMP NULL ,
  PRIMARY KEY (DOC_OBJECT_ID) ,
  CONSTRAINT fk_SCF_DEPENDENT_OBJ_SCF_OBJ1
    FOREIGN KEY (SIF_OBJECT_NAME )
    REFERENCES SCF_OBJECT (SIF_OBJECT_NAME ));

CREATE INDEX fk_SCF_DEPENDENT_OBJ_SCF_OBJ1 ON SCF_DOC_OBJECT (SIF_OBJECT_NAME ) ;

CREATE INDEX IX_DOC_OBJECT_NAME_KEY ON SCF_DOC_OBJECT (SIF_OBJECT_NAME , OBJECT_KEY_VALUE , APPLICATION_ID , ZONE_ID ) ;

CREATE INDEX IX_DOC_OBJECT_NAME_APPID ON SCF_DOC_OBJECT (SIF_OBJECT_NAME , APPLICATION_ID ) ;


-- -----------------------------------------------------
-- Table SCF_DOC_OBJECT_LIST
-- -----------------------------------------------------
CREATE  TABLE SCF_DOC_OBJECT_LIST (
  DO_CACHE_ID INTEGER  NOT NULL ,
  DEPENDENT_OBJECT_ID INTEGER  NOT NULL ,
  PRIMARY KEY (DO_CACHE_ID, DEPENDENT_OBJECT_ID) ,
  CONSTRAINT fk_SCF_OBJECT_LIST_SCF_DOC1
    FOREIGN KEY (DO_CACHE_ID )
    REFERENCES SCF_DO_CACHE (DO_CACHE_ID ),
  CONSTRAINT fk_SCF_OBJ_LIST_SCF_DEP_OBJ1
    FOREIGN KEY (DEPENDENT_OBJECT_ID )
    REFERENCES SCF_DOC_OBJECT (DOC_OBJECT_ID ));

CREATE INDEX fk_SCF_OBJ_LIST_SCF_DOC1 ON SCF_DOC_OBJECT_LIST (DO_CACHE_ID ) ;

CREATE INDEX fk_SCF_OBJ_LIST_SCF_DEP_OBJ1 ON SCF_DOC_OBJECT_LIST (DEPENDENT_OBJECT_ID ) ;


-- -----------------------------------------------------
-- Table SCF_DEPENDENCY_INFO
-- -----------------------------------------------------
CREATE  TABLE SCF_DEPENDENCY_INFO (
  DEPENDENCY_INFO_ID INTEGER  NOT NULL ,
  SIF_OBJECT_NAME VARCHAR(45) NULL ,
  PARENT_SIF_OBJECT_NAME VARCHAR(45) NULL  ,
  MULTIPLE BOOLEAN  NULL ,
  XPATH_TO_LIST VARCHAR(256) NULL ,
  PRIMARY KEY (DEPENDENCY_INFO_ID) ,
  CONSTRAINT fk_SCF_OBJECT_DEP_SCF_OBJ1
    FOREIGN KEY (SIF_OBJECT_NAME )
    REFERENCES SCF_OBJECT (SIF_OBJECT_NAME ),
  CONSTRAINT fk_SCF_OBJECT_DEP_SCF_OBJ2
    FOREIGN KEY (PARENT_SIF_OBJECT_NAME )
    REFERENCES SCF_OBJECT (SIF_OBJECT_NAME ));

CREATE INDEX fk_SCF_OBJECT_DEP_SCF_OBJ1 ON SCF_DEPENDENCY_INFO (SIF_OBJECT_NAME ) ;

CREATE INDEX fk_SCF_OBJECT_DEP_SCF_OBJ2 ON SCF_DEPENDENCY_INFO (PARENT_SIF_OBJECT_NAME ) ;


-- -----------------------------------------------------
-- Table SCF_DEPENDENCY_KEY_INFO
-- -----------------------------------------------------
CREATE  TABLE SCF_DEPENDENCY_KEY_INFO (
  DEPENDENCY_KEY_INFO_ID INTEGER  NOT NULL ,
  DEPENDENCY_INFO_ID INTEGER  NULL ,
  XPATH_TO_KEY VARCHAR(256) NOT NULL ,
  SORT_ORDER INTEGER  NULL ,
  IS_INDICATOR BOOLEAN  NOT NULL  ,
  PRIMARY KEY (DEPENDENCY_KEY_INFO_ID) ,
  CONSTRAINT fk_SCF_DEPKEYINFO_SCF_DEPINFO1
    FOREIGN KEY (DEPENDENCY_INFO_ID )
    REFERENCES SCF_DEPENDENCY_INFO (DEPENDENCY_INFO_ID ));

CREATE INDEX fk_SCF_DEPKEYINFO_SCF_DEPINFO1 ON SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_INFO_ID ) ;


-- -----------------------------------------------------
-- Table SCF_VALID_INDICATOR
-- -----------------------------------------------------
CREATE  TABLE SCF_VALID_INDICATOR (
  DEPENDENCY_KEY_INFO_ID INTEGER  NOT NULL ,
  SIF_OBJECT_NAME VARCHAR(45) NOT NULL ,
  PRIMARY KEY (DEPENDENCY_KEY_INFO_ID, SIF_OBJECT_NAME ) ,
 CONSTRAINT fk_SCF_VALIDIND_SCF_OBJ1
    FOREIGN KEY (SIF_OBJECT_NAME )
    REFERENCES SCF_OBJECT (SIF_OBJECT_NAME ),
  CONSTRAINT fk_SCFVALIDIND_SCFDEPKEYINFO1
    FOREIGN KEY (DEPENDENCY_KEY_INFO_ID )
    REFERENCES SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_KEY_INFO_ID ));

CREATE INDEX fk_SCF_VALIND_SCF_OBJ1 ON SCF_VALID_INDICATOR (SIF_OBJECT_NAME ) ;

CREATE INDEX fk_SCFVALIND_SCFDEPKEYINFO1 ON SCF_VALID_INDICATOR (DEPENDENCY_KEY_INFO_ID ) ;

-- -----------------------------------------------------
-- Sequence for AUTO_INCREMENT
-- -----------------------------------------------------
CREATE SEQUENCE HIBERNATE_SEQUENCE MINVALUE 1 MAXVALUE 9223372036854775807 INCREMENT BY 1 START WITH 1000 CACHE 10  ;

-- -----------------------------------------------------
-- Data for table SCF_OBJECT
-- -----------------------------------------------------

INSERT INTO SCF_OBJECT (SIF_OBJECT_NAME, KEY_SEPARATOR, DEFAULT_EXPIRY_IN_MINUTES, DEFAULT_EXPIRY_STRATEGY) VALUES ('StudentPersonal', NULL, 120, 'EXPIRE');
INSERT INTO SCF_OBJECT (SIF_OBJECT_NAME, KEY_SEPARATOR, DEFAULT_EXPIRY_IN_MINUTES, DEFAULT_EXPIRY_STRATEGY) VALUES ('SchoolInfo', NULL, 120, 'EXPIRE');
INSERT INTO SCF_OBJECT (SIF_OBJECT_NAME, KEY_SEPARATOR, DEFAULT_EXPIRY_IN_MINUTES, DEFAULT_EXPIRY_STRATEGY) VALUES ('StaffPersonal', NULL, 120, 'EXPIRE');
INSERT INTO SCF_OBJECT (SIF_OBJECT_NAME, KEY_SEPARATOR, DEFAULT_EXPIRY_IN_MINUTES, DEFAULT_EXPIRY_STRATEGY) VALUES ('StudentContactPersonal', NULL, 120, 'EXPIRE');
INSERT INTO SCF_OBJECT (SIF_OBJECT_NAME, KEY_SEPARATOR, DEFAULT_EXPIRY_IN_MINUTES, DEFAULT_EXPIRY_STRATEGY) VALUES ('StudentSchoolEnrollment', NULL, 120, 'EXPIRE');
INSERT INTO SCF_OBJECT (SIF_OBJECT_NAME, KEY_SEPARATOR, DEFAULT_EXPIRY_IN_MINUTES, DEFAULT_EXPIRY_STRATEGY) VALUES ('StaffAssignment', NULL, 120, 'EXPIRE');
INSERT INTO SCF_OBJECT (SIF_OBJECT_NAME, KEY_SEPARATOR, DEFAULT_EXPIRY_IN_MINUTES, DEFAULT_EXPIRY_STRATEGY) VALUES ('TeachingGroup', NULL, 120, 'EXPIRE');
INSERT INTO SCF_OBJECT (SIF_OBJECT_NAME, KEY_SEPARATOR, DEFAULT_EXPIRY_IN_MINUTES, DEFAULT_EXPIRY_STRATEGY) VALUES ('StudentContactRelationship', '|', 120, 'EXPIRE');
INSERT INTO SCF_OBJECT (SIF_OBJECT_NAME, KEY_SEPARATOR, DEFAULT_EXPIRY_IN_MINUTES, DEFAULT_EXPIRY_STRATEGY) VALUES ('Identity', NULL, 120, 'EXPIRE');

COMMIT;

-- -----------------------------------------------------
-- Data for table SCF_OBJECT_KEY
-- -----------------------------------------------------

INSERT INTO SCF_OBJECT_KEY (OBJECT_KEY_ID, SIF_OBJECT_NAME, XPATH_TO_KEY, SORT_ORDER) VALUES (1, 'StudentPersonal', '@RefId', 1);
INSERT INTO SCF_OBJECT_KEY (OBJECT_KEY_ID, SIF_OBJECT_NAME, XPATH_TO_KEY, SORT_ORDER) VALUES (2, 'SchoolInfo', '@RefId', 1);
INSERT INTO SCF_OBJECT_KEY (OBJECT_KEY_ID, SIF_OBJECT_NAME, XPATH_TO_KEY, SORT_ORDER) VALUES (3, 'StaffPersonal', '@RefId', 1);
INSERT INTO SCF_OBJECT_KEY (OBJECT_KEY_ID, SIF_OBJECT_NAME, XPATH_TO_KEY, SORT_ORDER) VALUES (4, 'StudentContactPersonal', '@RefId', 1);
INSERT INTO SCF_OBJECT_KEY (OBJECT_KEY_ID, SIF_OBJECT_NAME, XPATH_TO_KEY, SORT_ORDER) VALUES (5, 'StudentSchoolEnrollment', '@RefId', 1);
INSERT INTO SCF_OBJECT_KEY (OBJECT_KEY_ID, SIF_OBJECT_NAME, XPATH_TO_KEY, SORT_ORDER) VALUES (6, 'StaffAssignment', '@RefId', 1);
INSERT INTO SCF_OBJECT_KEY (OBJECT_KEY_ID, SIF_OBJECT_NAME, XPATH_TO_KEY, SORT_ORDER) VALUES (7, 'TeachingGroup', '@RefId', 1);
INSERT INTO SCF_OBJECT_KEY (OBJECT_KEY_ID, SIF_OBJECT_NAME, XPATH_TO_KEY, SORT_ORDER) VALUES (8, 'StudentContactRelationship', '@StudentPersonalRefId', 1);
INSERT INTO SCF_OBJECT_KEY (OBJECT_KEY_ID, SIF_OBJECT_NAME, XPATH_TO_KEY, SORT_ORDER) VALUES (9, 'StudentContactRelationship', '@StudentContactPersonalRefId', 2);
INSERT INTO SCF_OBJECT_KEY (OBJECT_KEY_ID, SIF_OBJECT_NAME, XPATH_TO_KEY, SORT_ORDER) VALUES (10, 'Identity', '@RefId', 1);

COMMIT;

-- -----------------------------------------------------
-- Data for table SCF_DEPENDENCY_INFO
-- -----------------------------------------------------

INSERT INTO SCF_DEPENDENCY_INFO (DEPENDENCY_INFO_ID, SIF_OBJECT_NAME, PARENT_SIF_OBJECT_NAME, MULTIPLE, XPATH_TO_LIST) VALUES (1, 'StudentSchoolEnrollment', 'StudentPersonal', false, NULL);
INSERT INTO SCF_DEPENDENCY_INFO (DEPENDENCY_INFO_ID, SIF_OBJECT_NAME, PARENT_SIF_OBJECT_NAME, MULTIPLE, XPATH_TO_LIST) VALUES (2, 'StudentSchoolEnrollment', 'SchoolInfo', false, NULL);
INSERT INTO SCF_DEPENDENCY_INFO (DEPENDENCY_INFO_ID, SIF_OBJECT_NAME, PARENT_SIF_OBJECT_NAME, MULTIPLE, XPATH_TO_LIST) VALUES (3, 'StaffAssignment', 'StaffPersonal', false, NULL);
INSERT INTO SCF_DEPENDENCY_INFO (DEPENDENCY_INFO_ID, SIF_OBJECT_NAME, PARENT_SIF_OBJECT_NAME, MULTIPLE, XPATH_TO_LIST) VALUES (4, 'StaffAssignment', 'SchoolInfo', false, NULL);
INSERT INTO SCF_DEPENDENCY_INFO (DEPENDENCY_INFO_ID, SIF_OBJECT_NAME, PARENT_SIF_OBJECT_NAME, MULTIPLE, XPATH_TO_LIST) VALUES (5, 'StudentContactRelationship', 'StudentPersonal', false, NULL);
INSERT INTO SCF_DEPENDENCY_INFO (DEPENDENCY_INFO_ID, SIF_OBJECT_NAME, PARENT_SIF_OBJECT_NAME, MULTIPLE, XPATH_TO_LIST) VALUES (6, 'StudentContactRelationship', 'StudentContactPersonal', false, NULL);
INSERT INTO SCF_DEPENDENCY_INFO (DEPENDENCY_INFO_ID, SIF_OBJECT_NAME, PARENT_SIF_OBJECT_NAME, MULTIPLE, XPATH_TO_LIST) VALUES (7, 'TeachingGroup', 'SchoolInfo', false, NULL);
INSERT INTO SCF_DEPENDENCY_INFO (DEPENDENCY_INFO_ID, SIF_OBJECT_NAME, PARENT_SIF_OBJECT_NAME, MULTIPLE, XPATH_TO_LIST) VALUES (8, 'TeachingGroup', 'StudentPersonal', true, 'StudentList/TeachingGroupStudent');
INSERT INTO SCF_DEPENDENCY_INFO (DEPENDENCY_INFO_ID, SIF_OBJECT_NAME, PARENT_SIF_OBJECT_NAME, MULTIPLE, XPATH_TO_LIST) VALUES (9, 'TeachingGroup', 'StaffPersonal', true, 'TeacherList/TeachingGroupTeacher');
INSERT INTO SCF_DEPENDENCY_INFO (DEPENDENCY_INFO_ID, SIF_OBJECT_NAME, PARENT_SIF_OBJECT_NAME, MULTIPLE, XPATH_TO_LIST) VALUES (10, 'Identity', NULL, false, NULL);

COMMIT;

-- -----------------------------------------------------
-- Data for table SCF_DEPENDENCY_KEY_INFO
-- -----------------------------------------------------

INSERT INTO SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_KEY_INFO_ID, DEPENDENCY_INFO_ID, XPATH_TO_KEY, SORT_ORDER, IS_INDICATOR) VALUES (1, 1, 'StudentPersonalRefId', 1, false);
INSERT INTO SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_KEY_INFO_ID, DEPENDENCY_INFO_ID, XPATH_TO_KEY, SORT_ORDER, IS_INDICATOR) VALUES (2, 2, 'SchoolInfoRefId', 1, false);
INSERT INTO SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_KEY_INFO_ID, DEPENDENCY_INFO_ID, XPATH_TO_KEY, SORT_ORDER, IS_INDICATOR) VALUES (3, 3, 'StaffPersonalRefId', 1, false);
INSERT INTO SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_KEY_INFO_ID, DEPENDENCY_INFO_ID, XPATH_TO_KEY, SORT_ORDER, IS_INDICATOR) VALUES (4, 4, 'SchoolInfoRefId', 1, false);
INSERT INTO SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_KEY_INFO_ID, DEPENDENCY_INFO_ID, XPATH_TO_KEY, SORT_ORDER, IS_INDICATOR) VALUES (5, 5, '@StudentPersonalRefId', 1, false);
INSERT INTO SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_KEY_INFO_ID, DEPENDENCY_INFO_ID, XPATH_TO_KEY, SORT_ORDER, IS_INDICATOR) VALUES (6, 6, '@StudentContactPersonalRefId', 1, false);
INSERT INTO SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_KEY_INFO_ID, DEPENDENCY_INFO_ID, XPATH_TO_KEY, SORT_ORDER, IS_INDICATOR) VALUES (7, 7, 'SchoolInfoRefID', 1, false);
INSERT INTO SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_KEY_INFO_ID, DEPENDENCY_INFO_ID, XPATH_TO_KEY, SORT_ORDER, IS_INDICATOR) VALUES (8, 8, 'StudentPersonalRefId', 1, false);
INSERT INTO SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_KEY_INFO_ID, DEPENDENCY_INFO_ID, XPATH_TO_KEY, SORT_ORDER, IS_INDICATOR) VALUES (9, 9, 'StaffPersonalRefId', 1, false);
INSERT INTO SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_KEY_INFO_ID, DEPENDENCY_INFO_ID, XPATH_TO_KEY, SORT_ORDER, IS_INDICATOR) VALUES (10, 10, 'SIF_RefId', 1, false);
INSERT INTO SCF_DEPENDENCY_KEY_INFO (DEPENDENCY_KEY_INFO_ID, DEPENDENCY_INFO_ID, XPATH_TO_KEY, SORT_ORDER, IS_INDICATOR) VALUES (11, 10, 'SIF_RefId/@SIF_RefObject', 1, true);

COMMIT;

-- -----------------------------------------------------
-- Data for table SCF_VALID_INDICATOR
-- -----------------------------------------------------

INSERT INTO SCF_VALID_INDICATOR (DEPENDENCY_KEY_INFO_ID, SIF_OBJECT_NAME) VALUES (11, 'StudentPersonal');
INSERT INTO SCF_VALID_INDICATOR (DEPENDENCY_KEY_INFO_ID, SIF_OBJECT_NAME) VALUES (11, 'StaffPersonal');
INSERT INTO SCF_VALID_INDICATOR (DEPENDENCY_KEY_INFO_ID, SIF_OBJECT_NAME) VALUES (11, 'StudentContactPersonal');

COMMIT;
